using System;
using System.IO;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Data;
using System.Text;

namespace GDIPac
{
	/// <summary>
	/// Summary description for Pac.
	/// </summary>
	public class Pac : Sprite
	{
		private ImageSet pacImageSet = new ImageSet();
		private const int initX = 8;
		private const int initY = 10;

		public Pac(IntPtr picBoxHandle, Playfield playfield) : base(picBoxHandle, playfield, null, Direction.East, false, false)
		{
			pacImageSet.SetImage(Direction.North, "pacUp1.bmp",    "pacUp2.bmp");
			pacImageSet.SetImage(Direction.South, "pacDown1.bmp",  "pacDown2.bmp");
			pacImageSet.SetImage(Direction.East,  "pacRight1.bmp", "pacRight2.bmp");
			pacImageSet.SetImage(Direction.West,  "pacLeft1.bmp",  "pacLeft2.bmp");

			SetImageSet(pacImageSet);

			X = initX;
			Y = initY;
		}

		protected override Direction ChooseNextDirection()
		{
			Keyboard key = Keyboard.GetInstance();

			if(key.KeyUp)
				return Direction.North;

			if(key.KeyDown)
				return Direction.South;

			if(key.KeyLeft)
				return Direction.West;

			if(key.KeyRight)
				return Direction.East;

			return CurrDirection;
		}

		protected override void DoExtraProcessing(bool isAnimAtZero)
		{
			if(isAnimAtZero)
			{
				if(playfield.IsPellet(X, Y))
				{
					playfield.ClearTile(X, Y);
					++Game.GetInstance().Score;
					playfield.NumPellets--;
				}

				if(playfield.IsPowerPellet(X, Y))
				{
					playfield.ClearTile(X, Y);
					Game.GetInstance().Score += 10;
					playfield.NumPellets--;

					SetAnimFast();
					Game.GetInstance().StartPowerPelletMode();
				}
			}
		}
	}
}
